pub struct ShelfAllocatorOptions {
pub alignment: Size2D<i32, UnknownUnit>,
pub vertical_shelves: bool,
pub num_columns: i32,
}Expand description
Options to tweak the behavior of the atlas allocator.
Fields
alignment: Size2D<i32, UnknownUnit>Align item sizes to a multiple of this alignment.
Default value: [1, 1] (no alignment).
vertical_shelves: boolUse vertical instead of horizontal shelves.
Default value: false.
num_columns: i32If possible split the allocator’s surface into multiple columns.
Having multiple columns allows having more (smaller shelves).
Default value: 1.